@@ -1,9 +1,11 @@
 -- 
 -- Created by SQL::Translator::Producer::MySQL
--- Created on Tue Mar  4 08:31:41 2014
+-- Created on Wed Mar  5 10:33:51 2014
 -- 
 SET foreign_key_checks=0;
 
+DROP TABLE IF EXISTS `HasDateOps`;
+
 --
 -- Table: `HasDateOps`
 --
